@@ -1,6 +1,6 @@
 /* actions.c
  *
- * Copyright  2002 Lutz Mller <lutz@users.sourceforge.net>
+ * Copyright 2002 Lutz Mller <lutz@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -705,6 +705,10 @@ action_camera_show_abilities (GPParams *p)
 		printf (_("                                 : Preview\n"));
 		has_capture = 1;
 	}
+	if (a.operations & GP_OPERATION_TRIGGER_CAPTURE) {
+		printf (_("                                 : Trigger Capture\n"));
+		has_capture = 1;
+	}
 	if (has_capture == 0) {
 		printf (_("                                 : Capture not supported by the driver\n"));
 	}
@@ -973,7 +977,8 @@ _action_camera_capture_preview (GPParams *p, int viewasciiart)
 		return (r);
 	}
 
-	r = save_camera_file_to_file (NULL, "capture_preview", GP_FILE_TYPE_NORMAL, file, tmpfilename);
+	/* name it file_%filename if --filename is set, otherwise capture_preview */
+	r = save_camera_file_to_file (NULL, "capture_preview", p->filename?GP_FILE_TYPE_PREVIEW:GP_FILE_TYPE_NORMAL, file, tmpfilename);
 	gp_file_unref (file);
 	if (r < 0) {
 		unlink (tmpname);
