@@ -148,7 +148,7 @@ static int
 get_path_for_file (const char *folder, const char *name, CameraFileType type, CameraFile *file, char **path)
 {
 	unsigned int i, l;
-	char *s, b[1024];
+	char *s = NULL, b[1024];
 	time_t t = 0;
 	struct tm *tm;
 	int hour12;
@@ -358,6 +358,14 @@ get_path_for_file (const char *folder, const char *name, CameraFileType type, Ca
 		}
 	}
 
+	/**
+	 * If the file is a capture_preview,
+	 * apply prefix over the calculated basename
+	 */
+	if (type == GP_FILE_TYPE_PREVIEW) {
+		return gp_file_get_name_by_type (file, s, type, path);
+	}
+
 	return (GP_OK);
 }
 
@@ -457,6 +465,8 @@ save_camera_file_to_file (
 						break;
 					}
 				}
+				close(out_fd);
+				close(in_fd);
 				unlink(curname);
 			} else
 				perror("rename");
@@ -1654,6 +1664,12 @@ cb_arg_run (poptContext __unused__ ctx,
 		GPPort		*port;
 		GPPortInfo	info;
 
+		/* If a camera is already open, close it, as we need a new port */
+		if (gp_params.camera) {
+			gp_camera_exit (gp_params.camera, gp_params.context);
+			/* exit, not free. will reopen on next command. */
+		}
+
 		params->p.r = gp_port_new (&port);
 		if (params->p.r != GP_OK) {
 			gp_log(GP_LOG_ERROR,"port_reset", "new failed %d", params->p.r);
@@ -1955,7 +1971,7 @@ main (int argc, char **argv, char **envp)
 		 N_("Set debug level [error|debug|data|all]"), NULL},
 		{"debug-logfile", '\0', POPT_ARG_STRING, (void *) &debug_logfile_name, ARG_DEBUG_LOGFILE,
 		 N_("Name of file to write debug info to"), N_("FILENAME")},
-		{"quiet", '\0', POPT_ARG_NONE, NULL, ARG_QUIET,
+		{"quiet", 'q', POPT_ARG_NONE, NULL, ARG_QUIET,
 		 N_("Quiet output (default=verbose)"), NULL},
 		{"hook-script", '\0', POPT_ARG_STRING, NULL, ARG_HOOK_SCRIPT,
 		 N_("Hook script to call after downloads, captures, etc."),
