@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  */
 
 #include "config.h"
@@ -23,6 +23,10 @@
 
 #include <stdlib.h>
 
+#ifndef HAVE_POPT
+# error gphoto2 REQUIRES popt!
+#endif
+
 static const char **gphoto2_frontend_version(GPVersionVerbosity verbose)
 {
 	/* we could also compute/parse the short strings from the long
@@ -34,12 +38,8 @@ static const char **gphoto2_frontend_version(GPVersionVerbosity verbose)
 #else
 		"unknown (C compiler used)",
 #endif
-#ifdef HAVE_POPT
-		"popt (for handling command-line parameters)",
-#else
-		"no popt (for handling command-line parameters)",
-#endif
-#ifdef HAVE_EXIF
+		"popt (mandatory, for handling command-line parameters)",
+#ifdef HAVE_LIBEXIF
 		"exif (for displaying EXIF information)",
 #else
 		"no exif (for displaying EXIF information)",
@@ -73,12 +73,8 @@ static const char **gphoto2_frontend_version(GPVersionVerbosity verbose)
 #else
 		"unknown cc",
 #endif
-#ifdef HAVE_POPT
-		"popt",
-#else
-		"no popt",
-#endif
-#ifdef HAVE_EXIF
+		"popt(m)",
+#ifdef HAVE_LIBEXIF
 		"exif",
 #else
 		"no exif",
@@ -114,3 +110,11 @@ const module_version module_versions[] = {
 	{ "libgphoto2_port", gp_port_library_version },
 	{ NULL, NULL }
 };
+
+
+/*
+ * Local Variables:
+ * c-file-style:"linux"
+ * indent-tabs-mode:t
+ * End:
+ */
